@@ -1,14 +1,19 @@
 import { ScriptLine, define } from "./types.js"
 
-type EnvConfig = { useOnCd: boolean; logLevel: string }
+type EnvConfig = {
+  useOnCd: boolean
+  logLevel: string
+  corepackEnabled: boolean
+}
 export type HasEnv = { env(cfg: Partial<EnvConfig>): ScriptLine }
 
 function stringify(envConfig: Partial<EnvConfig> = {}) {
-  const { useOnCd, logLevel } = envConfig
+  const { useOnCd, logLevel, corepackEnabled } = envConfig
   return [
     `fnm env`,
     useOnCd && "--use-on-cd",
     logLevel && `--log-level=${logLevel}`,
+    corepackEnabled && "--corepack-enabled",
   ]
     .filter(Boolean)
     .join(" ")
