@@ -43,7 +43,7 @@ pub enum Error {
 fn shells_as_string() -> String {
     AVAILABLE_SHELLS
         .iter()
-        .map(|x| format!("* {}", x))
+        .map(|x| format!("* {x}"))
         .collect::<Vec<_>>()
         .join("\n")
 }
