@@ -64,17 +64,16 @@ impl Command for Env {
         }
 
         let multishell_path = make_symlink(config)?;
+        let multishell_path_str = multishell_path.to_str().unwrap().to_owned();
+
         let binary_path = if cfg!(windows) {
-            multishell_path.clone()
+            multishell_path
         } else {
             multishell_path.join("bin")
         };
 
         let env_vars = HashMap::from([
-            (
-                "FNM_MULTISHELL_PATH",
-                multishell_path.to_str().unwrap().to_owned(),
-            ),
+            ("FNM_MULTISHELL_PATH", multishell_path_str),
             (
                 "FNM_VERSION_FILE_STRATEGY",
                 config.version_file_strategy().as_str().to_owned(),
@@ -91,6 +90,10 @@ impl Command for Env {
                 "FNM_NODE_DIST_MIRROR",
                 config.node_dist_mirror.as_str().to_owned(),
             ),
+            (
+                "FNM_COREPACK_ENABLED",
+                config.corepack_enabled().to_string(),
+            ),
             ("FNM_ARCH", config.arch.to_string()),
         ]);
 
@@ -114,7 +117,7 @@ impl Command for Env {
             println!("{}", shell.use_on_cd(config)?);
         }
         if let Some(v) = shell.rehash() {
-            println!("{}", v);
+            println!("{v}");
         }
 
         Ok(())
@@ -147,7 +150,7 @@ pub enum Error {
 fn shells_as_string() -> String {
     AVAILABLE_SHELLS
         .iter()
-        .map(|x| format!("* {}", x))
+        .map(|x| format!("* {x}"))
         .collect::<Vec<_>>()
         .join("\n")
 }
