@@ -7,6 +7,7 @@ mod zsh;
 
 #[allow(clippy::module_inception)]
 mod shell;
+mod windows_compat;
 
 pub use bash::Bash;
 pub use fish::Fish;
@@ -14,4 +15,5 @@ pub use infer::infer_shell;
 pub use powershell::PowerShell;
 pub use shell::{Shell, AVAILABLE_SHELLS};
 pub use windows_cmd::WindowsCmd;
+pub use windows_compat::maybe_fix_windows_path;
 pub use zsh::Zsh;
